@@ -131,9 +131,9 @@ QString dfmbase::FileInfo::nameOf(const NameInfoType type) const
     case FileNameInfoType::kFileNameOfRename:
         return dptr->fileName();
     case FileNameInfoType::kBaseName:
-        [[fallthrough]];
-    case FileNameInfoType::kBaseNameOfRename:
         return dptr->baseName();
+    case FileNameInfoType::kBaseNameOfRename:
+        [[fallthrough]];
     case FileNameInfoType::kCompleteBaseName:
         return dptr->completeBaseName();
     case FileNameInfoType::kSuffixOfRename:
@@ -302,13 +302,8 @@ QString dfmbase::FileInfo::displayOf(const DisPlayInfoType type) const
         return url.path();
     case DisPlayInfoType::kMimeTypeDisplayName:
         return MimeTypeDisplayManager::instance()->displayName(nameOf(FileNameInfoType::kMimeTypeName));
-    case DisPlayInfoType::kFileTypeDisplayName: {
-
-        int mimeDisplayNum = static_cast<int>(MimeTypeDisplayManager::
-                                                      instance()
-                                                              ->displayNameToEnum(const_cast<FileInfo *>(this)->fileMimeType().name()));
-        return QString("%1.").arg(mimeDisplayNum, 2, 10, QChar('0')).append(nameOf(FileNameInfoType::kSuffix));
-    }
+    case DisPlayInfoType::kFileTypeDisplayName:
+        return MimeTypeDisplayManager::instance()->fullMimeName(nameOf(FileNameInfoType::kMimeTypeName));
     case DisPlayInfoType::kFileDisplayPinyinName:
         if (pinyinName.isEmpty()) {
             const QString &displayName = this->displayOf(DisplayInfoType::kFileDisplayName);
@@ -396,8 +391,7 @@ bool dfmbase::FileInfo::canAttributes(const CanableInfoType type) const
 {
     switch (type) {
     case FileCanType::kCanFetch:
-        return isAttributes(OptInfoType::kIsDir)
-                && !isAttributes(OptInfoType::kIsPrivate);
+        return isAttributes(OptInfoType::kIsDir);
     case FileCanType::kCanDrop:
         return dptr->canDrop();
     case FileCanType::kCanDrag:
@@ -660,10 +654,6 @@ QString dfmbase::FileInfoPrivate::suffix() const
  */
 bool DFMBASE_NAMESPACE::FileInfoPrivate::canDrop() const
 {
-    if (q->isAttributes(OptInfoType::kIsPrivate)) {
-        return false;
-    }
-
     if (!q->isAttributes(OptInfoType::kIsSymLink)) {
         const bool isDesktop = q->nameOf(NameInfoType::kMimeTypeName) == Global::Mime::kTypeAppXDesktop;
         return (q->isAttributes(OptInfoType::kIsDir) && q->isAttributes(OptInfoType::kIsWritable)) || isDesktop;
