@@ -12,8 +12,6 @@
 #include <dfm-base/mimetype/mimetypedisplaymanager.h>
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/widgets/filemanagerwindowsmanager.h>
-#include <dfm-base/utils/clipboardmonitor.h>
-#include <dfm-base/utils/windowutils.h>
 
 #include <QApplication>
 #include <QClipboard>
@@ -36,16 +34,13 @@ static QMutex clipboardFileUrlsMutex;
 static QAtomicInt remoteCurrentCount = 0;
 static ClipBoard::ClipboardAction clipboardAction = ClipBoard::kUnknownAction;
 static std::atomic_bool canReadClipboard { true };
-static std::atomic_bool hasUosRemote { false };
-static ClipboardMonitor *clipMonitor { nullptr };
-static std::atomic_bool isX11 { false };
 
 static constexpr char kUserIdKey[] = "userId";
 static constexpr char kRemoteCopyKey[] = "uos/remote-copy";
 static constexpr char kGnomeCopyKey[] = "x-special/gnome-copied-files";
 static constexpr char kRemoteAssistanceCopyKey[] = "uos/remote-copied-files";
 
-void onClipboardDataChanged(const QStringList &formats)
+void onClipboardDataChanged()
 {
     if (!canReadClipboard)
         return;
@@ -53,29 +48,29 @@ void onClipboardDataChanged(const QStringList &formats)
     QMutexLocker lk(&clipboardFileUrlsMutex);
     clipboardFileUrls.clear();
 
-    if (formats.isEmpty()) {
-        qCWarning(logDFMBase) << "get empty mimeData formats from QClipBoard!";
+    const QMimeData *mimeData = qApp->clipboard()->mimeData();
+    if (!mimeData || mimeData->formats().isEmpty()) {
+        qCWarning(logDFMBase) << "get null mimeData from QClipBoard or remote formats is null!";
         return;
     }
-
-    if (formats.contains(kRemoteCopyKey) || hasUosRemote) {
-        qCInfo(logDFMBase) << "clipboard use other !";
+    if (mimeData->hasFormat(kRemoteCopyKey)) {
+        qCWarning(logDFMBase) << "clipboard use other !";
         clipboardAction = ClipBoard::kRemoteAction;
         remoteCurrentCount++;
         return;
     }
     // 远程协助功能
-    if (formats.contains(kRemoteAssistanceCopyKey)) {
+    if (mimeData->hasFormat(kRemoteAssistanceCopyKey)) {
         qCInfo(logDFMBase) << "Remote copy: set remote copy action";
         clipboardAction = ClipBoard::kRemoteCopiedAction;
         return;
     }
-    if (!formats.contains(kGnomeCopyKey)) {
+    // 没有文件拷贝
+    if (!mimeData->hasFormat(kGnomeCopyKey)) {
         qCWarning(logDFMBase) << "no kGnomeCopyKey target in mimedata formats!";
         clipboardAction = ClipBoard::kUnknownAction;
         return;
     }
-    const QMimeData *mimeData = qApp->clipboard()->mimeData();
     const QString &data = mimeData->data(kGnomeCopyKey);
     const static QRegularExpression regCut("cut\nfile://"), regCopy("copy\nfile://");
     if (data.contains(regCut)) {
@@ -83,7 +78,7 @@ void onClipboardDataChanged(const QStringList &formats)
     } else if (data.contains(regCopy)) {
         clipboardAction = ClipBoard::kCopyAction;
     } else {
-        qCWarning(logDFMBase) << "wrong kGnomeCopyKey data = " << data << mimeData->formats();
+        qCWarning(logDFMBase) << "wrong kGnomeCopyKey data = " << data;
         clipboardAction = ClipBoard::kUnknownAction;
     }
 
@@ -97,15 +92,8 @@ void onClipboardDataChanged(const QStringList &formats)
 ClipBoard::ClipBoard(QObject *parent)
     : QObject(parent)
 {
-    init();
-}
-
-void ClipBoard::init()
-{
-    QLibrary library("libdisplayjack-clipboard.so");
-    qCritical() << library.fileName();
     connect(qApp->clipboard(), &QClipboard::dataChanged, this, [this]() {
-        onClipboardDataChanged(qApp->clipboard()->mimeData()->formats());
+        onClipboardDataChanged();
         emit clipboardDataChanged();
     });
 
@@ -116,20 +104,6 @@ void ClipBoard::init()
     connect(&FileManagerWindowsManager::instance(), &FileManagerWindowsManager::lastWindowClosed, this, [] {
         GlobalData::canReadClipboard = false;
     });
-
-    if (!WindowUtils ::isWayLand() || !library.load())
-        return;
-
-    library.unload();
-    qCWarning(logDFMBase()) << "connect x11 clipboard changed single!!!!";
-    GlobalData::isX11 = true;
-    GlobalData::clipMonitor = new ClipboardMonitor;
-    connect(GlobalData::clipMonitor, &ClipboardMonitor::clipboardChanged, this, [](const QStringList &formats) {
-        qInfo() << " * Clipboard formats changed: " << formats;
-        GlobalData::hasUosRemote = formats.contains(GlobalData::kRemoteCopyKey);
-    });
-
-    GlobalData::clipMonitor->start();
 }
 
 ClipBoard *ClipBoard::instance()
@@ -174,7 +148,7 @@ void ClipBoard::setUrlsToClipboard(const QList<QUrl> &list, ClipBoard::Clipboard
             const FileInfoPointer &info = InfoFactory::create<FileInfo>(qurl, Global::CreateFileInfoType::kCreateFileInfoAuto, &error);
 
             if (!info) {
-                qCWarning(logDFMBase) << QString("create file info error, case : %1").arg(error);
+                qCWarning(logDFMBase) << "Failed to create file info for URL:" << qurl << "error:" << error;
                 continue;
             }
             QStringList iconList;
@@ -232,7 +206,7 @@ void ClipBoard::setCurUrlToClipboardForRemote(const QUrl &curUrl)
     if (curUrl.isLocalFile()) {
         localPath = curUrl.toString().toLocal8Bit();
     } else {
-        qCInfo(logDFMBase) << "Remote Assistance copy: current url not local file";
+        qCWarning(logDFMBase) << "Remote assistance copy failed: URL is not a local file:" << curUrl;
         return;
     }
 
@@ -242,6 +216,7 @@ void ClipBoard::setCurUrlToClipboardForRemote(const QUrl &curUrl)
     mimeData->setData(GlobalData::kRemoteAssistanceCopyKey, localPath);
     mimeData->setText(curUrl.toString());
     qApp->clipboard()->setMimeData(mimeData);
+    qCInfo(logDFMBase) << "Remote assistance clipboard data set for URL:" << curUrl;
 }
 /*!
  * \brief ClipBoard::setDataToClopboard Set user data to clipboard
@@ -250,11 +225,12 @@ void ClipBoard::setCurUrlToClipboardForRemote(const QUrl &curUrl)
 void ClipBoard::setDataToClipboard(QMimeData *mimeData)
 {
     if (!mimeData) {
-        qCWarning(logDFMBase) << "set data to clipboard failed, mimeData is null!";
+        qCWarning(logDFMBase) << "Failed to set clipboard data: mimeData is null";
         return;
     }
 
     qApp->clipboard()->setMimeData(mimeData);
+    qCDebug(logDFMBase) << "Custom mime data set to clipboard successfully";
 }
 
 /*!
@@ -338,21 +314,6 @@ void ClipBoard::replaceClipboardUrl(const QUrl &oldUrl, const QUrl &newUrl)
     setUrlsToClipboard(clipboardUrls, action);
 }
 
-void ClipBoard::readFirstClipboard()
-{
-    QStringList mime;
-    if (GlobalData::isX11) {
-        static bool first = false;
-        if (first)
-            return;
-        first = true;
-        mime = getFirstMimeTypesByX11();
-    } else {
-        mime = qApp->clipboard()->mimeData()->formats();
-    }
-
-    onClipboardDataChanged(mime);
-}
 /*!
  * \brief ClipBoard::getUrlsByX11 Use X11 to read URLs downloaded
  * remotely from the clipboard
@@ -363,11 +324,11 @@ QList<QUrl> ClipBoard::getUrlsByX11()
     QAtomicInt currentCount = GlobalData::remoteCurrentCount;
     const QMimeData *mimedata = qApp->clipboard()->mimeData();
     if (!mimedata) {
-        qCWarning(logDFMBase) << "the clipboard mimedata is invalid!";
+        qCWarning(logDFMBase) << "X11 clipboard access failed: invalid mime data";
         return QList<QUrl>();
     }
     if (GlobalData::clipboardAction != kRemoteAction) {
-        qCWarning(logDFMBase) << "current action is not RemoteAction ,error action " << GlobalData::clipboardAction;
+        qCWarning(logDFMBase) << "X11 clipboard read failed: current action is not remote action, got:" << GlobalData::clipboardAction;
         return QList<QUrl>();
     }
     // 使用x11创建一个窗口去阻塞获取URl
@@ -460,7 +421,7 @@ QList<QUrl> ClipBoard::getUrlsByX11()
     XCloseDisplay(display);
 
     if (isCanceled) {
-        qCWarning(logDFMBase) << "user cancel remote download !";
+        qCWarning(logDFMBase) << "X11 remote download cancelled by user";
         return QList<QUrl>();
     }
 
@@ -490,48 +451,7 @@ QList<QUrl> ClipBoard::getUrlsByX11()
     return clipboardFileUrls;
 }
 
-QStringList ClipBoard::getFirstMimeTypesByX11()
+void ClipBoard::onClipboardDataChanged()
 {
-    // 使用x11创建一个窗口去阻塞获取URl
-    Display *display = XOpenDisplay(nullptr);
-    unsigned long color = BlackPixel(display, DefaultScreen(display));
-    Window window = XCreateSimpleWindow(display, DefaultRootWindow(display), 0, 0, 1, 1, 0, color, color);
-
-    char *result = nullptr;
-    unsigned long ressize = 0, restail = 0;
-    int resbits;
-    Atom bufid = XInternAtom(display, "CLIPBOARD", False),
-         fmtid = XInternAtom(display, "TARGETS", False),
-         propid = XInternAtom(display, "XSEL_DATA", False);
-    XEvent event;
-
-    QList<QUrl> urls;
-    QString results;
-
-    XSelectInput(display, window, PropertyChangeMask);
-    XConvertSelection(display, bufid, fmtid, propid, window, CurrentTime);
-    QList<QUrl> currentClipboardFileUrls;
-    do {
-        XNextEvent(display, &event);
-    } while (event.type != SelectionNotify || event.xselection.selection != bufid);
-
-    XGetWindowProperty(display, window, propid, 0, LONG_MAX / 4, True, AnyPropertyType,
-                       &fmtid, &resbits, &ressize, &restail, reinterpret_cast<unsigned char **>(&result));
-    QStringList formats;
-    if (resbits == 32 && ressize > 0) {
-        Atom *atoms = reinterpret_cast<Atom *>(result);
-        for (int i = 0; i < static_cast<int>(ressize); i++) {
-            formats.append(XGetAtomName(display, atoms[i]));
-        }
-        qCWarning(logDFMBase) << "first x11 read formats = " << formats;
-    }
-    XFree(result);
-    XDestroyWindow(display, window);
-    XCloseDisplay(display);
-    return formats;
-}
-
-void ClipBoard::onClipboardDataChanged(const QStringList &mimeTypes)
-{
-    GlobalData::onClipboardDataChanged(mimeTypes);
+    GlobalData::onClipboardDataChanged();
 }
