@@ -359,11 +359,8 @@ bool FileUtils::isCdRomDevice(const QUrl &url)
 
 bool FileUtils::trashIsEmpty()
 {
-    const auto &cifsHost = NetworkUtils::cifsMountHostInfo();
-    if (!cifsHost.isEmpty()) {
-        const auto &mountPoint = cifsHost.constKeyValueBegin()->first;
-        if (NetworkUtils::instance()->checkFtpOrSmbBusy(QUrl::fromLocalFile(mountPoint)))
-            return true;
+    if (NetworkUtils::instance()->checkAllCIFSBusy()) {
+        return true;
     }
 
     // not use cache, because some times info unreliable, such as watcher inited temporality
@@ -918,6 +915,8 @@ void FileUtils::notifyFileChangeManual(DFMGLOBAL_NAMESPACE::FileNotifyType type,
             return true;
         if (ProtocolUtils::isNFSFile(url))
             return true;
+        if (ProtocolUtils::isDavFile(url) || ProtocolUtils::isDavsFile(url))
+            return true;
 
         return false;
     };
