@@ -16,6 +16,8 @@ bool isFTPFile(const QUrl &url);
 bool isSFTPFile(const QUrl &url);
 bool isSMBFile(const QUrl &url);
 bool isNFSFile(const QUrl &url);
+bool isDavFile(const QUrl &url);
+bool isDavsFile(const QUrl &url);
 }   // namespace ProtocolUtils
 
 DFMBASE_END_NAMESPACE
