@@ -28,11 +28,22 @@ CustomDToolButton::CustomDToolButton(QWidget *parent)
 void CustomDToolButton::initStyleOption(QStyleOptionToolButton *option) const
 {
     DToolButton::initStyleOption(option);
-    if (underMouse()) {
+    if (isEnabled()) {
         bool isDarkTheme = DGuiApplicationHelper::instance()->themeType() == DGuiApplicationHelper::DarkType;
-        QColor hoverColor = isDarkTheme ? QColor(255, 255, 255, 15)
-                                        : QColor(0, 0, 0, 26);
-        option->palette.setColor(QPalette::Button, hoverColor);
+        DStyleHelper dstyle(style());
+        const int radius = dstyle.pixelMetric(DStyle::PM_FrameRadius);
+
+        QColor bgColor;
+        if (isDown()) {
+            // 按下状态 - 20%不透明度
+            bgColor = isDarkTheme ? QColor(255, 255, 255, 51)
+                                  : QColor(0, 0, 0, 51);
+        } else if (underMouse()) {
+            // 悬浮状态 - 10%不透明度
+            bgColor = isDarkTheme ? QColor(255, 255, 255, 26)
+                                  : QColor(0, 0, 0, 26);
+        }
+        option->palette.setColor(QPalette::Button, bgColor);
     }
 }
 
