@@ -11,6 +11,7 @@
 #include <dfm-base/utils/sysinfoutils.h>
 #include <dfm-base/utils/networkutils.h>
 #include <dfm-base/utils/fileutils.h>
+#include <dfm-base/utils/systemservicemanager.h>
 #include <dfm-base/widgets/filemanagerwindowsmanager.h>
 
 #include <dfm-framework/event/event.h>
@@ -46,8 +47,7 @@ static constexpr char kInterfaceInterface[] { "org.deepin.Filemanager.UserShareM
 static constexpr char kFuncIsPasswordSet[] { "IsUserSharePasswordSet" };
 static constexpr char kFuncSetPasswd[] { "SetUserSharePassword" };
 static constexpr char kFuncCloseShare[] { "CloseSmbShareByShareName" };
-static constexpr char kFuncEnableSmbServices[] { "EnableSmbServices" };
-}   // namespace DBusINterfaceInfo
+}   // namespace DaemonServiceIFace
 
 namespace ShareConfig {
 static constexpr char kShareConfigPath[] { "/var/lib/samba/usershares" };
@@ -58,18 +58,6 @@ static constexpr char kShareComment[] { "comment" };
 static constexpr char kGuestOk[] { "guest_ok" };
 }   // namespace ShareConfig
 
-namespace SambaServiceIFace {
-static constexpr char kService[] { "org.freedesktop.systemd1" };
-static constexpr char kPath[] { "/org/freedesktop/systemd1/unit/smbd_2eservice" };
-static constexpr char kInterface[] { "org.freedesktop.systemd1.Unit" };
-
-static constexpr char kPropertySubState[] { "SubState" };
-static constexpr char kExpectedSubState[] { "running" };
-
-static constexpr char kFuncStart[] { "Start" };
-static constexpr char kParamReplace[] { "replace" };
-}
-
 UserShareHelper *UserShareHelper::instance()
 {
     static UserShareHelper helper;
@@ -181,7 +169,8 @@ void UserShareHelper::setSambaPasswd(const QString &userName, const QString &pas
     }
 
     // Call D-Bus interface with pipe file descriptor
-    QDBusReply<bool> reply = userShareInter->call(DaemonServiceIFace::kFuncSetPasswd, QVariant::fromValue(fd));
+    QDBusInterface *interface = getUserShareInterface();
+    QDBusReply<bool> reply = interface->call(DaemonServiceIFace::kFuncSetPasswd, QVariant::fromValue(fd));
     bool success = reply.isValid() && reply.value();
     fmInfo() << "Samba password set result:" << success
              << ", error msg:" << (reply.isValid() ? "none" : reply.error().message());
@@ -258,14 +247,8 @@ void UserShareHelper::handleSetPassword(const QString &newPassword)
 
 bool UserShareHelper::isSambaServiceRunning()
 {
-    QDBusInterface iface(SambaServiceIFace::kService, SambaServiceIFace::kPath, SambaServiceIFace::kInterface, QDBusConnection::systemBus());
-
-    if (iface.isValid()) {
-        const QVariant &variantStatus = iface.property(SambaServiceIFace::kPropertySubState);   // 获取属性 SubState，等同于 systemctl status smbd 结果 Active 值
-        if (variantStatus.isValid())
-            return SambaServiceIFace::kExpectedSubState == variantStatus.toString();
-    }
-    return false;
+    // 使用 SystemServiceManager 统一检查服务状态（遵循 DRY 原则）
+    return SystemServiceManager::instance().isServiceRunning("smbd.service");
 }
 
 void UserShareHelper::startSambaServiceAsync(StartSambaFinished onFinished)
@@ -369,7 +352,8 @@ bool UserShareHelper::needDisableShareWidget(FileInfoPointer info)
 
 bool UserShareHelper::isUserSharePasswordSet(const QString &username)
 {
-    QDBusReply<bool> reply = userShareInter->call(DaemonServiceIFace::kFuncIsPasswordSet, username);
+    QDBusInterface *interface = getUserShareInterface();
+    QDBusReply<bool> reply = interface->call(DaemonServiceIFace::kFuncIsPasswordSet, username);
     bool result = reply.isValid() ? reply.value() : false;
     fmDebug() << "isSharePasswordSet result: " << result << ", error: " << reply.error();
 
@@ -501,7 +485,8 @@ void UserShareHelper::initMonitorPath()
 
 bool UserShareHelper::removeShareByShareName(const QString &name, bool silent)
 {
-    QDBusReply<bool> reply = userShareInter->asyncCall(DaemonServiceIFace::kFuncCloseShare, name, !silent);
+    QDBusInterface *interface = getUserShareInterface();
+    QDBusReply<bool> reply = interface->asyncCall(DaemonServiceIFace::kFuncCloseShare, name, !silent);
     if (reply.isValid() && reply.value()) {
         fmDebug() << "share closed: " << name;
         runNetCmd(QStringList() << "usershare"
@@ -633,25 +618,21 @@ int UserShareHelper::validShareInfoCount() const
 
 QPair<bool, QString> UserShareHelper::startSmbService()
 {
-    QDBusInterface iface(SambaServiceIFace::kService, SambaServiceIFace::kPath, SambaServiceIFace::kInterface, QDBusConnection::systemBus());
-    QDBusPendingReply<QDBusObjectPath> reply = iface.asyncCall(SambaServiceIFace::kFuncStart, SambaServiceIFace::kParamReplace);
-    reply.waitForFinished();
-    if (reply.isValid()) {
-        const QString &errMsg = reply.error().message();
-        if (errMsg.isEmpty()) {
-            if (!setSmbdAutoStart())
-                fmWarning() << "auto start smbd failed.";
-            return { true, "" };
-        }
+    QString errMsg;
+    // 使用 SystemServiceManager 统一管理服务启动和启用
+    bool smbdOk = SystemServiceManager::instance().enableServiceNow("smbd.service");
+    if (!smbdOk) {
+        errMsg = "Failed to start and enable smbd.service";
         return { false, errMsg };
     }
-    return { false, "restart smbd failed" };
-}
 
-bool UserShareHelper::setSmbdAutoStart()
-{
-    QDBusReply<bool> reply = userShareInter->call(DaemonServiceIFace::kFuncEnableSmbServices);
-    return reply.value();
+    bool nmbdOk = SystemServiceManager::instance().enableServiceNow("nmbd.service");
+    if (!nmbdOk) {
+        errMsg = "Failed to start and enable nmbd.service";
+        return { false, errMsg };
+    }
+
+    return { true, "" };
 }
 
 bool UserShareHelper::isValidShare(const QVariantMap &info) const
@@ -686,8 +667,7 @@ void UserShareHelper::emitShareRemoveFailed(const QString &path)
 UserShareHelper::UserShareHelper(QObject *parent)
     : QObject(parent)
 {
-    userShareInter.reset(new QDBusInterface(DaemonServiceIFace::kInterfaceService, DaemonServiceIFace::kInterfacePath, DaemonServiceIFace::kInterfaceInterface, QDBusConnection::systemBus(), this));
-
+    // D-Bus interface will be lazily initialized on first use to avoid unnecessary service activation
     watcherManager = new ShareWatcherManager(this);
     watcherManager->add(ShareConfig::kShareConfigPath);
 
@@ -696,4 +676,22 @@ UserShareHelper::UserShareHelper(QObject *parent)
 
     initMonitorPath();
 }
+
+QDBusInterface *UserShareHelper::getUserShareInterface()
+{
+    if (!userShareInter) {
+        fmInfo() << "Initializing UserShare D-Bus interface on first use";
+        userShareInter.reset(new QDBusInterface(
+                DaemonServiceIFace::kInterfaceService,
+                DaemonServiceIFace::kInterfacePath,
+                DaemonServiceIFace::kInterfaceInterface,
+                QDBusConnection::systemBus(),
+                this));
+
+        if (!userShareInter->isValid()) {
+            fmWarning() << "Failed to create UserShare D-Bus interface:" << userShareInter->lastError().message();
+        }
+    }
+    return userShareInter.data();
+}
 }
