@@ -83,7 +83,6 @@ private:
     int validShareInfoCount() const;
 
     QPair<bool, QString> startSmbService();
-    bool setSmbdAutoStart();
 
     bool isValidShare(const ShareInfo &info) const;
 
@@ -92,6 +91,9 @@ private:
     void emitShareRemoved(const QString &path);
     void emitShareRemoveFailed(const QString &path);
 
+    // Lazy initialization for D-Bus interface to avoid unnecessary service activation
+    QDBusInterface *getUserShareInterface();
+
 private:
     QTimer *pollingSharesTimer;
     QSharedPointer<QDBusInterface> userShareInter { nullptr };
