@@ -103,26 +103,6 @@ void FileOperateBaseWorker::emitSpeedUpdatedNotify(const qint64 &writSize)
     emit speedUpdatedNotify(info);
 }
 
-/*!
- * \brief FileOperateBaseWorker::setTargetPermissions Set permissions on the target file
- * \param fromInfo File information of source file
- * \param toInfo File information of target file
- */
-void FileOperateBaseWorker::setTargetPermissions(const QUrl &fromUrl, const QUrl &toUrl)
-{
-    // 修改文件修改时间
-    const auto &fromInfo = InfoFactory::create<FileInfo>(fromUrl, Global::CreateFileInfoType::kCreateFileInfoSync);
-    const auto &toInfo = InfoFactory::create<FileInfo>(toUrl, Global::CreateFileInfoType::kCreateFileInfoSync);
-    localFileHandler->setFileTime(toInfo->urlOf(UrlInfoType::kUrl),
-                                  fromInfo->timeOf(TimeInfoType::kLastRead).value<QDateTime>(),
-                                  fromInfo->timeOf(TimeInfoType::kLastModified).value<QDateTime>());
-    QFileDevice::Permissions permissions = fromInfo->permissions();
-    QString path = fromInfo->urlOf(UrlInfoType::kUrl).path();
-    // 权限为0000时，源文件已经被删除，无需修改新建的文件的权限为0000
-    if (permissions != 0000 && !ProtocolUtils::isMTPFile(toInfo->urlOf(UrlInfoType::kUrl)))
-        localFileHandler->setPermissions(toInfo->urlOf(UrlInfoType::kUrl), permissions);
-}
-
 /*!
  * \brief FileOperateBaseWorker::readAheadSourceFile Pre read source file content
  * \param fileInfo File information of source file
@@ -652,13 +632,28 @@ bool FileOperateBaseWorker::checkAndCopyFile(const DFileInfoPointer fromInfo, co
     auto fromSize = fromInfo->attribute(DFileInfo::AttributeID::kStandardSize).toLongLong();
     // check file file size bigger than 4 GB
     if (!checkFileSize(fromSize, fromInfo->uri(),
-                       toInfo->uri(), skip))
+                       toInfo->uri(), skip)) {
         return false;
-    bool isSameLocalDevice = isSourceFileLocal && isTargetFileLocal
-            && FileUtils::isSameDevice(fromInfo->uri(), targetUrl);
-    return isSameLocalDevice
-            ? doCopyLocalByRange(fromInfo, toInfo, skip)
-            : doCopyOtherFile(fromInfo, toInfo, skip);
+    }
+
+    if (jobType == AbstractJobHandler::JobType::kCutType)
+        return doCopyOtherFile(fromInfo, toInfo, skip);
+
+    if (isSourceFileLocal && isTargetFileLocal && !workData->singleThread) {
+        while (bigFileCopy && !isStopped()) {
+            QThread::msleep(10);
+        }
+        if (fromSize > bigFileSize && FileUtils::isSameDevice(fromInfo->uri(), targetUrl)) {
+            bigFileCopy = true;
+            auto result = doCopyLocalByRange(fromInfo, toInfo, skip);
+            bigFileCopy = false;
+            return result;
+        }
+        return doCopyLocalFile(fromInfo, toInfo);
+    }
+
+    // copy other file or cut file
+    return doCopyOtherFile(fromInfo, toInfo, skip);
 }
 
 bool FileOperateBaseWorker::checkAndCopyDir(const DFileInfoPointer &fromInfo, const DFileInfoPointer &toInfo, bool *skip)
@@ -763,13 +758,30 @@ bool FileOperateBaseWorker::checkAndCopyDir(const DFileInfoPointer &fromInfo, co
     return true;
 }
 
+void FileOperateBaseWorker::waitThreadPoolOver()
+{
+    // wait all thread start
+    if (!isStopped() && threadPool) {
+        QThread::msleep(10);
+    }
+    // wait thread pool copy local file or copy big file over
+    while (threadPool && threadPool->activeThreadCount() > 0) {
+        QThread::msleep(10);
+    }
+}
+
 // waitThreadPoolOver method removed - no longer needed without multi-threading
 
 void FileOperateBaseWorker::initCopyWay()
 {
-    // Simplified: always use single thread for file copying
-    countWriteType = CountWriteSizeType::kCustomizeType;
-    workData->signalThread = true;   // Force single thread
+    if (isSourceFileLocal && isTargetFileLocal) {
+        countWriteType = CountWriteSizeType::kCustomizeType;
+        workData->singleThread = (sourceFilesCount > 1 || sourceFilesTotalSize > FileOperationsUtils::bigFileSize()) && FileUtils::getCpuProcessCount() > 4
+                ? false
+                : true;
+        if (!workData->singleThread)
+            threadCount = FileUtils::getCpuProcessCount() < 4 ? 2 : 4;
+    }
 
     if (ProtocolUtils::isSMBFile(targetUrl)
         || ProtocolUtils::isFTPFile(targetUrl)
@@ -781,6 +793,10 @@ void FileOperateBaseWorker::initCopyWay()
         fmDebug() << "Using kWriteBlockType for progress counting";
     }
 
+    if (!workData->singleThread) {
+        initThreadCopy();
+    }
+
     copyTid = (countWriteType == CountWriteSizeType::kTidType) ? syscall(SYS_gettid) : -1;
 }
 
@@ -859,6 +875,21 @@ void FileOperateBaseWorker::setSkipValue(bool *skip, AbstractJobHandler::Support
         *skip = action == AbstractJobHandler::SupportAction::kSkipAction;
 }
 
+void FileOperateBaseWorker::initThreadCopy()
+{
+    for (int i = 0; i < threadCount; i++) {
+        QSharedPointer<DoCopyFileWorker> copy(new DoCopyFileWorker(workData));
+        // todo init new
+        connect(copy.data(), &DoCopyFileWorker::errorNotify, this, &FileOperateBaseWorker::emitErrorNotify, Qt::DirectConnection);
+        connect(copy.data(), &DoCopyFileWorker::currentTask, this, &FileOperateBaseWorker::emitCurrentTaskNotify, Qt::DirectConnection);
+        connect(copy.data(), &DoCopyFileWorker::retryErrSuccess, this, &FileOperateBaseWorker::retryErrSuccess, Qt::DirectConnection);
+        threadCopyWorker.append(copy);
+    }
+
+    threadPool.reset(new QThreadPool);
+    threadPool->setMaxThreadCount(threadCount);
+}
+
 void FileOperateBaseWorker::initSignalCopyWorker()
 {
     if (!copyOtherFileWorker) {
@@ -879,8 +910,22 @@ QUrl FileOperateBaseWorker::createNewTargetUrl(const DFileInfoPointer &toInfo, c
     return newTargetUrl;
 }
 
+bool FileOperateBaseWorker::doCopyLocalFile(const DFileInfoPointer fromInfo, const DFileInfoPointer toInfo)
+{
+    if (!stateCheck())
+        return false;
+
+    threadPool->start([this, fromInfo, toInfo]() {
+        threadCopyWorker[threadCopyFileCount % threadCount]->doFileCopy(fromInfo, toInfo);
+    });
+
+    threadCopyFileCount++;
+    return true;
+}
+
 bool FileOperateBaseWorker::doCopyLocalByRange(const DFileInfoPointer fromInfo, const DFileInfoPointer toInfo, bool *skip)
 {
+    waitThreadPoolOver();
     initSignalCopyWorker();
     const QString &targetUrl = toInfo->uri().toString();
 
