@@ -51,7 +51,6 @@ public:
                        const QUrl &toUrl, bool *skip);
     bool checkDiskSpaceAvailable(const QUrl &fromUrl, const QUrl &toUrl, bool *skip);
     bool checkTotalDiskSpaceAvailable(const QUrl &fromUrl, const QUrl &toUrl, bool *skip);
-    void setTargetPermissions(const QUrl &fromUrl, const QUrl &toUrl);
     void setAllDirPermisson();
     void determineCountProcessType();
     qint64 getWriteDataSize();
@@ -87,6 +86,7 @@ public:
     bool checkAndCopyDir(const DFileInfoPointer &fromInfo, const DFileInfoPointer &toInfo, bool *skip);
 
 protected:
+    void waitThreadPoolOver();
     void initCopyWay();
     bool shouldUseBlockWriteType() const;
     QUrl trashInfo(const DFileInfoPointer &fromInfo);
@@ -95,9 +95,11 @@ protected:
     void setSkipValue(bool *skip, AbstractJobHandler::SupportAction action);
 
 private:
+    void initThreadCopy();
     void initSignalCopyWorker();
     bool actionOperating(const AbstractJobHandler::SupportAction action, const qint64 size, bool *skip);
     QUrl createNewTargetUrl(const DFileInfoPointer &toInfo, const QString &fileName);
+    bool doCopyLocalFile(const DFileInfoPointer fromInfo, const DFileInfoPointer toInfo);
     bool doCopyOtherFile(const DFileInfoPointer fromInfo, const DFileInfoPointer toInfo, bool *skip);
     bool doCopyLocalByRange(const DFileInfoPointer fromInfo, const DFileInfoPointer toInfo, bool *skip);
 
@@ -130,6 +132,7 @@ protected:
     QFuture<void> syncResult;
     QString blocakTargetRootPath;
 
+    std::atomic_int threadCopyFileCount { 0 };
     QList<DFileInfoPointer> cutAndDeleteFiles;
 };
 DPFILEOPERATIONS_END_NAMESPACE
