@@ -87,11 +87,13 @@ bool PropertyMenuScene::initialize(const QVariantHash &params)
         d->selectFiles << d->currentDir;
     }
 
-    QString errString;
-    d->focusFileInfo = DFMBASE_NAMESPACE::InfoFactory::create<FileInfo>(d->focusFile, Global::CreateFileInfoType::kCreateFileInfoAuto, &errString);
-    if (d->focusFileInfo.isNull()) {
-        fmDebug() << errString;
-        return false;
+    if (!d->isEmptyArea) {
+        QString errString;
+        d->focusFileInfo = DFMBASE_NAMESPACE::InfoFactory::create<FileInfo>(d->focusFile, Global::CreateFileInfoType::kCreateFileInfoAuto, &errString);
+        if (d->focusFileInfo.isNull()) {
+            fmDebug() << errString;
+            return false;
+        }
     }
 
     return AbstractMenuScene::initialize(params);
@@ -126,7 +128,7 @@ void PropertyMenuScene::updateState(QMenu *parent)
         return;
 
     if (auto pAction = d->predicateAction.value(PropertyActionId::kProperty)) {
-        if (!d->focusFileInfo->exists())
+        if (!d->isEmptyArea && !d->focusFileInfo->exists())
             pAction->setDisabled(true);
     }
 
