@@ -11,6 +11,7 @@
 #include "extensionimpl/virtualextensionimplplugin.h"
 #include "vaultassist/virtualvaulthelperplugin.h"
 #include "testing/virtualtestingplugin.h"
+#include "shred/vitrualshredplugin.h"
 
 namespace dfmplugin_utils {
 DFM_LOG_REGISTER_CATEGORY(DPUTILS_NAMESPACE)
@@ -23,6 +24,7 @@ static constexpr char kOpenWith[] { "dfmplugin-openwith" };
 static constexpr char kExtensionImpl[] { "dfmplugin-extensionimpl" };
 static constexpr char kVaultAssist[] { "dfmplugin-vaultassist" };
 static constexpr char kTesting[] { "dfmplugin-testing" };
+static constexpr char kShred[] { "dfmplugin-shred" };
 
 QSharedPointer<DPF_NAMESPACE::Plugin> Utils::create(const QString &pluginName)
 {
@@ -68,6 +70,11 @@ QSharedPointer<DPF_NAMESPACE::Plugin> Utils::create(const QString &pluginName)
         return plugin;
     }
 
+    if (pluginName == kShred) {
+        QSharedPointer<DPF_NAMESPACE::Plugin> plugin { new VirtualShredPlugin };
+        return plugin;
+    }
+
     return {};
 }
 }   // namespace dfmplugin_utils
