@@ -2,15 +2,11 @@
 //
 // SPDX-License-Identifier: GPL-3.0-or-later
 
-#ifdef COMPILE_ON_V2X
-#    include "backgrounddde.h"
-#else
-#    include "backgroundwm.h"
-#endif
+#include "backgrounddde.h"
 #include "backgroundmanager.h"
 #include "backgroundmanager_p.h"
 #include "backgrounddefault.h"
-#include "desktoputils/ddpugin_eventinterface_helper.h"
+#include "desktoputils/ddplugin_eventinterface_helper.h"
 
 #include <dfm-base/dfm_desktop_defines.h>
 #include <dfm-base/utils/universalutils.h>
@@ -71,12 +67,7 @@ bool BackgroundManagerPrivate::isEnableBackground()
 BackgroundManager::BackgroundManager(QObject *parent)
     : QObject(parent), d(new BackgroundManagerPrivate(this))
 {
-    d->service =
-#ifdef COMPILE_ON_V2X
-            new BackgroundDDE(this);
-#else
-            new BackgroundWM(this);
-#endif
+    d->service = new BackgroundDDE(this);
 
     d->bridge = new BackgroundBridge(d);
 }
