@@ -845,12 +845,13 @@ QRectF CanvasItemDelegate::paintEmblems(QPainter *painter, const QRectF &rect, c
 
 void CanvasItemDelegate::paintBackground(QPainter *painter, const QStyleOptionViewItem &option, const QRect &iconRect) const
 {
-    bool isSelected = (option.state & QStyle::State_Selected) && option.showDecorationSelected;
+    bool isDragMode = (static_cast<QPaintDevice *>(parent()->viewport()) != painter->device());
+    bool isSelected = !isDragMode && (option.state & QStyle::State_Selected) && option.showDecorationSelected;
     if (!isSelected)
         return;
 
-    QColor backgroundColor(0, 0, 0, qRound(255 * 0.15));
-    QColor borderColor(255, 255, 255, qRound(255 * 0.1));
+    QColor backgroundColor(33, 33, 33, qRound(255 * 0.25));
+    QColor borderColor(241, 241, 241, qRound(255 * 0.25));
     QRect backgroundRect = iconRect.adjusted(-kIconBackgroundMargin, -kIconBackgroundMargin, kIconBackgroundMargin, kIconBackgroundMargin);
 
     painter->save();
