@@ -38,13 +38,13 @@ void FileInfoModelPrivate::doRefresh()
 QIcon FileInfoModelPrivate::fileIcon(FileInfoPointer info)
 {
     using namespace dfmbase::Global;
-    const auto &vaule = info->extendAttributes(ExtInfoType::kFileThumbnail);
-    if (!vaule.isValid()) {
+    const auto &value = info->extendAttributes(ExtInfoType::kFileThumbnail);
+    if (!value.isValid()) {
         ThumbnailFactory::instance()->joinThumbnailJob(info->urlOf(UrlInfoType::kUrl), Global::kLarge);
         // make sure the thumbnail is generated only once
         info->setExtendedAttributes(ExtInfoType::kFileThumbnail, QIcon());
     } else {
-        const auto &thumbIcon = vaule.value<QIcon>();
+        const auto &thumbIcon = value.value<QIcon>();
         if (!thumbIcon.isNull())
             return thumbIcon;
     }
