@@ -15,11 +15,13 @@
 #include <dfm-base/utils/universalutils.h>
 #include <dfm-base/dfm_global_defines.h>
 #include <dfm-base/utils/protocolutils.h>
+#include <dfm-base/base/device/devicealiasmanager.h>
 
 #include <QRegularExpression>
 
 using namespace dfmplugin_computer;
 using namespace GlobalServerDefines;
+DFMBASE_USE_NAMESPACE
 
 /*!
  * \class ProtocolEntryFileEntity
@@ -39,15 +41,41 @@ ProtocolEntryFileEntity::ProtocolEntryFileEntity(const QUrl &url)
 QString ProtocolEntryFileEntity::displayName() const
 {
     QString displayName = datas.value(DeviceProperty::kDisplayName).toString();
+    const auto &alias = NPDeviceAliasManager::instance()->getAlias(targetUrl());
 
     QString host, share;
     bool isSmb = dfmbase::DeviceUtils::parseSmbInfo(displayName, host, share);
-    if (isSmb)
-        displayName = tr("%1 on %2").arg(share).arg(host);
+    if (isSmb) {
+        if (alias.isEmpty())
+            displayName = tr("%1 on %2").arg(share, host);
+        else
+            displayName = tr("%1 on %2").arg(share, alias);
+    } else if (!alias.isEmpty()) {
+        static QRegularExpression ipRegex(R"([0-9]{1,3}(?:\.[0-9]{1,3}){3})");
+        displayName.replace(ipRegex, alias);
+    }
 
     return displayName;
 }
 
+QString ProtocolEntryFileEntity::editDisplayText() const
+{
+    const auto &url = targetUrl();
+    const auto &alias = NPDeviceAliasManager::instance()->getAlias(url);
+    if (!alias.isEmpty())
+        return alias;
+
+    if (!url.host().isEmpty())
+        return url.host();
+
+    QString devId = datas.value(DeviceProperty::kId).toString();
+    QUrl idUrl(devId);
+    if (!idUrl.host().isEmpty())
+        return idUrl.host();
+
+    return displayName();
+}
+
 QIcon ProtocolEntryFileEntity::icon() const
 {
     auto icons = datas.value(DeviceProperty::kDeviceIcon).toStringList();
@@ -127,15 +155,19 @@ void ProtocolEntryFileEntity::refresh()
 QUrl ProtocolEntryFileEntity::targetUrl() const
 {
     auto mpt = datas.value(DeviceProperty::kMountPoint).toString();
-    QUrl target;
     if (mpt.isEmpty()) {
         fmDebug() << "No mount point found for protocol device:" << entryUrl;
-        return target;
+        return QUrl();
     }
 
-    target.setScheme(DFMBASE_NAMESPACE::Global::Scheme::kFile);
-    target.setPath(mpt);
+    QUrl target = QUrl::fromLocalFile(mpt);
     if (DFMBASE_NAMESPACE::ProtocolUtils::isSMBFile(target))
         return DFMBASE_NAMESPACE::DeviceUtils::getSambaFileUriFromNative(target);
+
     return target;
 }
+
+bool ProtocolEntryFileEntity::renamable() const
+{
+    return DFMBASE_NAMESPACE::NPDeviceAliasManager::instance()->canSetAlias(targetUrl());
+}
