@@ -179,6 +179,12 @@ QVariant ComputerModel::data(const QModelIndex &index, int role) const
     case kDisplayNameIsElidedRole:
         return item->isElided;
 
+    case kEditDisplayTextRole:
+        return item->info ? item->info->editDisplayText() : "";
+
+    case kItemVisibleRole:
+        return item->isVisible;
+
     default:
         return {};
     }
@@ -207,6 +213,9 @@ bool ComputerModel::setData(const QModelIndex &index, const QVariant &value, int
     } else if (role == DataRoles::kDisplayNameIsElidedRole) {
         item.isElided = value.toBool();
         return true;
+    } else if (role == DataRoles::kItemVisibleRole) {
+        item.isVisible = value.toBool();
+        return true;
     }
     return false;
 }
@@ -259,6 +268,21 @@ int ComputerModel::findSplitter(const QString &group)
     return -1;
 }
 
+ComputerItemData ComputerModel::findItemData(const QUrl &target)
+{
+    auto iter = std::find_if(items.cbegin(), items.cend(), [=](const ComputerItemData &item) {
+        return UniversalUtils::urlEquals(item.url, target);
+    });
+    if (iter != items.cend())
+        return *iter;
+    return {};
+}
+
+const QList<ComputerItemData> &ComputerModel::itemList()
+{
+    return items;
+}
+
 void ComputerModel::initConnect()
 {
     connect(ComputerItemWatcherInstance, &ComputerItemWatcher::itemQueryFinished, this, [this](const ComputerDataList &datas) {
