@@ -21,6 +21,7 @@
 #include <QDBusReply>
 
 #include <DDialog>
+#include <DDBusSender>
 
 #ifdef COMPILE_ON_V2X
 #    define APP_MANAGER_SERVICE "org.deepin.dde.SessionManager1"
@@ -71,6 +72,7 @@ void EventsHandler::bindDaemonSignals()
     conn("DecryptResult", SLOT(onDecryptFinished(const QVariantMap &)));
     conn("ChangePassResult", SLOT(onChgPwdFinished(const QVariantMap &)));
     conn("WaitAuthInput", SLOT(onRequestAuthArgs(const QVariantMap &)));
+    conn("OverlayDMModeChanged", SLOT(onOverlayDMModeChanged(bool, int)));
 }
 
 void EventsHandler::hookEvents()
@@ -209,13 +211,13 @@ void EventsHandler::onEncryptFinished(const QVariantMap &result)
     case kSuccess:
     case KErrorRequestExportRecKey:
         title = tr("Encrypt done");
-        msg = tr("Device %1 has been encrypted").arg(device);
+        msg = tr("Partition %1 has been encrypted").arg(device);
         success = true;
         fmInfo() << "Encryption completed successfully for device:" << device;
         break;
     default:
         title = tr("Encrypt failed");
-        msg = tr("Device %1 encrypt failed, please see log for more information.(%2)")
+        msg = tr("Partition %1 encrypt failed, please see log for more information.(%2)")
                       .arg(device)
                       .arg(code);
         fmWarning() << "Encryption failed for device:" << device << "with code:" << code;
@@ -226,14 +228,13 @@ void EventsHandler::onEncryptFinished(const QVariantMap &result)
     if (!dialog)
         dialog_utils::showDialog(title, msg, code != 0 ? dialog_utils::kError : dialog_utils::kInfo);
     else {
-        auto pos = dialog->geometry().topLeft();
         dialog->showResultPage(success, title, msg);
         if (code == -KErrorRequestExportRecKey) {
             auto recKey = result.value(encrypt_param_keys::kKeyRecoveryKey).toString();
             dialog->setRecoveryKey(recKey, dev);
             dialog->showExportPage();
         }
-        dialog->move(pos);
+        dialog->raise();
     }
 
     // delete auto start file.
@@ -325,7 +326,7 @@ void EventsHandler::onEncryptProgress(const QString &dev, const QString &devName
         QString device = QString("%1(%2)").arg(devName).arg(dev.mid(5));
 
         QApplication::restoreOverrideCursor();
-        auto dlg = new EncryptProgressDialog(qApp->activeWindow());
+        auto dlg = new EncryptProgressDialog();
         dlg->setText(tr("%1 is under encrypting...").arg(device),
                      tr("The encrypting process may have system lag, please minimize the system operation"));
         encryptDialogs.insert(dev, dlg);
@@ -346,7 +347,7 @@ void EventsHandler::onDecryptProgress(const QString &dev, const QString &devName
         QString device = QString("%1(%2)").arg(devName).arg(dev.mid(5));
 
         QApplication::restoreOverrideCursor();
-        auto dlg = new EncryptProgressDialog(qApp->activeWindow());
+        auto dlg = new EncryptProgressDialog();
         dlg->setText(tr("%1 is under decrypting...").arg(device),
                      tr("The decrypting process may have system lag, please minimize the system operation"));
         decryptDialogs.insert(dev, dlg);
@@ -483,7 +484,7 @@ void EventsHandler::showPreEncryptError(const QString &dev, const QString &devNa
     switch (-code) {
     case (kSuccess):
         title = tr("Preencrypt done");
-        msg = tr("Device %1 has been preencrypt, please reboot to finish encryption.")
+        msg = tr("Partition %1 has been preencrypt, please reboot to finish encryption.")
                       .arg(device);
         fmInfo() << "Pre-encryption successful for device:" << device;
         break;
@@ -492,7 +493,7 @@ void EventsHandler::showPreEncryptError(const QString &dev, const QString &devNa
         return;
     default:
         title = tr("Preencrypt failed");
-        msg = tr("Device %1 preencrypt failed, please see log for more information.(%2)")
+        msg = tr("Partition %1 preencrypt failed, please see log for more information.(%2)")
                       .arg(device)
                       .arg(code);
         showError = true;
@@ -514,7 +515,7 @@ void EventsHandler::showDecryptError(const QString &dev, const QString &devName,
     switch (-code) {
     case (kSuccess):
         title = tr("Decrypt done");
-        msg = tr("Device %1 has been decrypted").arg(device);
+        msg = tr("Partition %1 has been decrypted").arg(device);
         showFailed = false;
         fmInfo() << "Decryption successful for device:" << device;
         break;
@@ -522,19 +523,19 @@ void EventsHandler::showDecryptError(const QString &dev, const QString &devName,
         fmInfo() << "Decryption cancelled by user for device:" << device;
         return;
     case kErrorWrongPassphrase:
-        title = tr("Decrypt disk");
+        title = tr("Decrypt partition");
         msg = tr("Wrong passpharse or PIN");
         fmWarning() << "Wrong passphrase/PIN for device:" << device;
         break;
     case kErrorNotFullyEncrypted:
         title = tr("Decrypt failed");
-        msg = tr("Device %1 is under encrypting, please decrypt after encryption finished.")
+        msg = tr("Partition %1 is under encrypting, please decrypt after encryption finished.")
                       .arg(device);
         fmWarning() << "Device not fully encrypted:" << device;
         break;
     default:
         title = tr("Decrypt failed");
-        msg = tr("Device %1 Decrypt failed, please see log for more information.(%2)")
+        msg = tr("Partition %1 Decrypt failed, please see log for more information.(%2)")
                       .arg(device)
                       .arg(code);
         fmWarning() << "Decryption failed for device:" << device << "code:" << code;
@@ -543,9 +544,8 @@ void EventsHandler::showDecryptError(const QString &dev, const QString &devName,
 
     auto dialog = decryptDialogs.take(dev);
     if (dialog) {
-        auto pos = dialog->geometry().topLeft();
         dialog->showResultPage(code == 0, title, msg);
-        dialog->move(pos);
+        dialog->raise();
     } else {
         dialog_utils::showDialog(title, msg,
                                  showFailed ? dialog_utils::kError : dialog_utils::kInfo);
@@ -587,7 +587,7 @@ void EventsHandler::showChgPwdError(const QString &dev, const QString &devName,
         break;
     default:
         title = tr("Change %1 failed").arg(codeType);
-        msg = tr("Device %1 change %2 failed, please see log for more information.(%3)")
+        msg = tr("Partition %1 change %2 failed, please see log for more information.(%3)")
                       .arg(device)
                       .arg(codeType)
                       .arg(code);
@@ -619,7 +619,7 @@ bool EventsHandler::canUnlock(const QString &device)
     if (device == unfinishedDecryptJob()) {
         fmWarning() << "Device has unfinished decryption job:" << device;
         dialog_utils::showDialog(tr("Error"),
-                                 tr("Device is not fully decrypted, please finish decryption before access."),
+                                 tr("Partition is not fully decrypted, please finish decryption before access."),
                                  dialog_utils::DialogType::kInfo);
         return false;
     }
@@ -627,8 +627,8 @@ bool EventsHandler::canUnlock(const QString &device)
     int states = EventsHandler::instance()->deviceEncryptStatus(device);
     if ((states & kStatusOnline) && (states & kStatusEncrypt)) {
         fmWarning() << "Device is online and encrypting, cannot unlock:" << device << "status:" << states;
-        dialog_utils::showDialog(tr("Unlocking device failed"),
-                                 tr("Please click the right disk menu \"Continue partition encryption\" to complete partition encryption."),
+        dialog_utils::showDialog(tr("Unlocking partition failed"),
+                                 tr("Please click \"Continue Partition Encryption\" in the right-click menu to complete the partition encryption."),
                                  dialog_utils::DialogType::kError);
         return false;
     }
@@ -645,6 +645,61 @@ void EventsHandler::autoStartDFM()
     sessMng.asyncCall("AddAutostart", QString(kReencryptDesktopFile));
 }
 
+void EventsHandler::onOverlayDMModeChanged(bool enabled, int result)
+{
+    fmInfo() << "Overlay DM mode changed, enabled:" << enabled << "result:" << result;
+
+    QString title, message, icon;
+    bool isSuccess = (result == 0);
+
+    if (isSuccess) {
+        // Operation succeeded, reboot required
+        icon = "dde-file-manager";
+        if (enabled) {
+            title = tr("Partition Encryption Non-Reboot Mode Enabled");
+            message = tr("Partition Encryption Non-Reboot Mode has been enabled successfully. "
+                         "Please reboot your system for the changes to take effect. After reboot, "
+                         "partition encryption operations will not require system restart.");
+        } else {
+            title = tr("Partition Encryption Non-Reboot Mode Disabled");
+            message = tr("Partition Encryption Non-Reboot Mode has been disabled successfully. "
+                         "Please reboot your system for the changes to take effect. After reboot, "
+                         "partition encryption operations will require system restart.");
+        }
+        fmInfo() << "Sending success notification:" << title << message;
+    } else {
+        // Operation failed
+        icon = "dialog-error";
+        title = tr("Operation Failed");
+        if (enabled) {
+            message = tr("Failed to enable Partition Encryption Non-Reboot Mode. "
+                         "The system may not support this feature or encountered an error during initramfs update.");
+        } else {
+            message = tr("Failed to disable Partition Encryption Non-Reboot Mode. "
+                         "An error occurred during initramfs update.");
+        }
+        fmCritical() << "Sending failure notification:" << title << message;
+    }
+
+    // Send desktop notification
+    DDBusSender()
+            .service("org.freedesktop.Notifications")
+            .path("/org/freedesktop/Notifications")
+            .interface("org.freedesktop.Notifications")
+            .method("Notify")
+            .arg(tr("dde-file-manager"))
+            .arg(static_cast<uint>(0))
+            .arg(icon)
+            .arg(title)
+            .arg(message)
+            .arg(QStringList())
+            .arg(QVariantMap())
+            .arg(10000)  // 10 seconds timeout
+            .call();
+}
+
+
+
 EventsHandler::EventsHandler(QObject *parent)
     : QObject { parent }
 {
