@@ -4,6 +4,7 @@
 
 #include "dfmplugin_disk_encrypt_global.h"
 #include "diskencryptmenuscene.h"
+#include "globaltypesdefine.h"
 #include "gui/decryptparamsinputdialog.h"
 #include "gui/chgpassphrasedialog.h"
 #include "gui/unlockpartitiondialog.h"
@@ -26,11 +27,14 @@
 #include <QJsonDocument>
 #include <QJsonObject>
 #include <QJsonParseError>
+#include <QDBusUnixFileDescriptor>
+#include <QDataStream>
 
 #include <ddialog.h>
 #include <dconfig.h>
 
 #include <fstab.h>
+#include <unistd.h>
 
 DFMBASE_USE_NAMESPACE
 using namespace dfmplugin_diskenc;
@@ -127,11 +131,21 @@ bool DiskEncryptMenuScene::initialize(const QVariantHash &params)
         return false;
     }
 
+    auto mpts = selectedItemInfo.value("MountPoints").toStringList();
+    if (mpts.contains("/") && QStorageInfo("/").device() == QStorageInfo("/boot").device()) {
+        fmInfo() << "No separated Boot device, / cannot be encrypted.";
+        return false;
+    }
+
     param.jobType = job_type::TypeNormal;
     if (isOverlay) {
         param.jobType = job_type::TypeOverlay;
     } else {
         auto configJson = selectedItemInfo.value("Configuration", "").toString();
+        if (selectedItemInfo.value("ClearBlockDeviceInfo").toHash().contains("Configuration")) {
+            configJson = selectedItemInfo.value("ClearBlockDeviceInfo").toHash().value("Configuration").toString();
+        }
+
         if (!configJson.isEmpty()) {
             QJsonParseError err;
             QJsonDocument doc = QJsonDocument::fromJson(configJson.toLocal8Bit(), &err);
@@ -140,7 +154,9 @@ bool DiskEncryptMenuScene::initialize(const QVariantHash &params)
                 return false;
             }
             auto obj = doc.object();
-            param.jobType = job_type::TypeFstab;
+            if (obj.contains("fstab"))
+                param.jobType = job_type::TypeFstab;
+            fmInfo() << device << "device configuration" << configJson << ", job type set to" << param.jobType;
         }
     }
 
@@ -150,7 +166,7 @@ bool DiskEncryptMenuScene::initialize(const QVariantHash &params)
     param.deviceDisplayName = info->displayOf(dfmbase::FileInfo::kFileDisplayName);
     param.secType = SecKeyType::kPwd;
 
-    if (param.states & EncryptState::kStatusFinished) {
+    if (param.states != kStatusNotEncrypted) {
         param.secType = static_cast<SecKeyType>(device_utils::encKeyType(device));
         fmDebug() << "Device encryption finished, security type:" << param.secType;
     }
@@ -205,16 +221,25 @@ bool DiskEncryptMenuScene::triggered(QAction *action)
     } else if (actID == kActIDDecrypt || actID == kActIDResumeDecrypt) {
         fmInfo() << "Decrypt/resume decrypt action triggered for device:" << param.devDesc;
         QString displayName = QString("%1(%2)").arg(param.deviceDisplayName).arg(param.devDesc.mid(5));
-        if (dialog_utils::showConfirmDecryptionDialog(displayName, param.jobType == job_type::TypeFstab) != QDialog::Accepted) {
+
+        if (dialog_utils::showConfirmDecryptionDialog(displayName, false) != QDialog::Accepted) {
             fmDebug() << "Decryption dialog cancelled by user";
             return true;
         }
-        if (param.jobType == job_type::TypeNormal)
+
+        if (param.jobType == job_type::TypeNormal) {
             unmountBefore(decryptDevice, param);
-        else if (param.jobType == job_type::TypeOverlay)
+        } else if (param.jobType == job_type::TypeOverlay) {
+            // 在新的方案中，即便是需要重启的加密方案，在卷头初始化完成后，都会堆叠一层 dm 设备
+            // 以便可以进行非重启的取消加密动作。复用 overlay 的方案。
             decryptDevice(param);
-        else if (param.jobType == job_type::TypeFstab)
-            doDecryptDevice(param);
+        } else {
+            // 原 fstab 类型设备的取消加密动作，现应该走 overlay 的取消加密流程
+            qWarning() << "something might be wrong, unsupported job type for decryption:"
+                       << param.jobType
+                       << param.devDesc;
+            return false;
+        }
     } else if (actID == kActIDChangePwd) {
         fmInfo() << "Change passphrase action triggered for device:" << param.devDesc;
         changePassphrase(param);
@@ -237,7 +262,14 @@ void DiskEncryptMenuScene::updateState(QMenu *parent)
 void DiskEncryptMenuScene::encryptDevice(const DeviceEncryptParam &param)
 {
     QString displayName = QString("%1(%2)").arg(param.deviceDisplayName).arg(param.devDesc.mid(5));
-    bool needreboot = param.jobType == job_type::TypeFstab;
+
+    // TypeFstab 始终需要重启
+    // TypeOverlay 在禁用 useOverlayDMMode 配置时需要重启
+    //   当以 fstab 方式加密完成后，设备会被堆叠一层 dm 设备，以便可以在运行时取消加密；取消加密之后，再次
+    //   启动加密动作，设备会被识别为 overlay 类型，所以是否需要重启，在此时要考虑 useOverlayDMMode 配置项
+    bool needreboot = (param.jobType == job_type::TypeFstab)
+            || (param.jobType == job_type::TypeOverlay && !config_utils::useOverlayDMMode());
+
     int ret = dialog_utils::showConfirmEncryptionDialog(displayName, needreboot);
     if (ret != QDialog::Accepted) return;
 
@@ -246,7 +278,9 @@ void DiskEncryptMenuScene::encryptDevice(const DeviceEncryptParam &param)
         unmountBefore(doEncryptDevice, param);
     } else {
         fmDebug() << "Special job type, proceeding directly to encryption";
-        doEncryptDevice(param);
+        auto _param = param;
+        _param.jobType = needreboot ? job_type::TypeFstab : job_type::TypeOverlay;
+        doEncryptDevice(_param);
     }
 }
 
@@ -367,7 +401,8 @@ void DiskEncryptMenuScene::doEncryptDevice(const DeviceEncryptParam &param)
             { encrypt_param_keys::kKeyDevice, param.devDesc },
             { encrypt_param_keys::kKeyDeviceName, param.deviceDisplayName },
             { encrypt_param_keys::kKeyMountPoint, param.mountPoint },
-            { encrypt_param_keys::kKeyJobType, param.jobType }
+            { encrypt_param_keys::kKeyJobType, param.jobType },
+            { encrypt_param_keys::kKeyPhyDevice, param.devPhy }
         };
 
         fmDebug() << "Calling InitEncryption D-Bus method";
@@ -395,23 +430,24 @@ void DiskEncryptMenuScene::doReencryptDevice(const DeviceEncryptParam &param)
                          kDaemonBusPath,
                          kDaemonBusIface,
                          QDBusConnection::systemBus());
-    if (iface.isValid()) {
-        QVariantMap params {
-            { encrypt_param_keys::kKeyDevice, param.devDesc },
-            { encrypt_param_keys::kKeyPassphrase, toBase64(param.key) },
-            { encrypt_param_keys::kKeyExportToPath, param.exportPath },
-        };
-        if (!tpmToken.isEmpty()) params.insert(encrypt_param_keys::kKeyTPMToken, tpmToken);
-
-        fmDebug() << "Starting device re-encryption";
-        QDBusReply<bool> ret = iface.call("SetupAuthArgs", params);
-        if (ret.value()) {
-            QApplication::setOverrideCursor(Qt::WaitCursor);
-        } else {
-            fmCritical() << "Re-encryption setup failed";
-        }
-    } else {
+    if (!iface.isValid()) {
         fmCritical() << "Failed to create D-Bus interface for re-encryption";
+        return;
+    }
+
+    // Prepare credentials data
+    QVariantMap params {
+        { encrypt_param_keys::kKeyDevice, param.devDesc },
+        { encrypt_param_keys::kKeyPassphrase, toBase64(param.key) },
+        { encrypt_param_keys::kKeyExportToPath, param.exportPath },
+    };
+    if (!tpmToken.isEmpty())
+        params.insert(encrypt_param_keys::kKeyTPMToken, tpmToken);
+
+    // Send credentials via fd
+    fmDebug() << "Starting device re-encryption via fd";
+    if (sendCredentialsViaFd(iface, "SetupAuthArgs", params, true)) {
+        QApplication::setOverrideCursor(Qt::WaitCursor);
     }
 }
 
@@ -421,25 +457,26 @@ void DiskEncryptMenuScene::doDecryptDevice(const DeviceEncryptParam &param)
                          kDaemonBusPath,
                          kDaemonBusIface,
                          QDBusConnection::systemBus());
-    if (iface.isValid()) {
-        QVariantMap params {
-            { encrypt_param_keys::kKeyJobType, param.jobType },
-            { encrypt_param_keys::kKeyDevice, param.devDesc },
-            { encrypt_param_keys::kKeyDeviceName, param.deviceDisplayName },
-            { encrypt_param_keys::kKeyPassphrase, toBase64(param.key) }
-        };
+    if (!iface.isValid()) {
+        fmCritical() << "Failed to create D-Bus interface for decryption";
+        return;
+    }
 
-        fmDebug() << "Calling Decryption D-Bus method";
-        QDBusReply<bool> ret = iface.call("Decryption", params);
-        if (ret.value()) {
-            QApplication::setOverrideCursor(Qt::WaitCursor);
-        } else {
-            fmCritical() << "Decryption failed to start";
-        }
+    // Prepare credentials data
+    QVariantMap params {
+        { encrypt_param_keys::kKeyJobType, param.jobType },
+        { encrypt_param_keys::kKeyDevice, param.devDesc },
+        { encrypt_param_keys::kKeyDeviceName, param.deviceDisplayName },
+        { encrypt_param_keys::kKeyPassphrase, toBase64(param.key) }
+    };
 
+    // Send credentials via fd
+    fmDebug() << "Calling Decryption D-Bus method via fd";
+    if (sendCredentialsViaFd(iface, "Decryption", params, false)) {
+        QApplication::setOverrideCursor(Qt::WaitCursor);
         EventsHandler::instance()->autoStartDFM();
     } else {
-        fmCritical() << "Failed to create D-Bus interface for decryption";
+        fmCritical() << "Decryption failed to start";
     }
 }
 
@@ -474,6 +511,16 @@ void DiskEncryptMenuScene::doChangePassphrase(const DeviceEncryptParam &param)
                          kDaemonBusIface,
                          QDBusConnection::systemBus());
     if (iface.isValid()) {
+        // Create anonymous pipe for secure credential transmission
+        int pipefd[2];
+        if (pipe(pipefd) == -1) {
+            fmCritical() << "Failed to create anonymous pipe for credentials";
+            return;
+        }
+
+        // Prepare credentials data using QDataStream for reliable serialization
+        QByteArray credentials;
+        QDataStream stream(&credentials, QIODevice::WriteOnly);
         QVariantMap params {
             { encrypt_param_keys::kKeyDevice, param.devDesc },
             { encrypt_param_keys::kKeyPassphrase, toBase64(param.newKey) },
@@ -482,14 +529,36 @@ void DiskEncryptMenuScene::doChangePassphrase(const DeviceEncryptParam &param)
             { encrypt_param_keys::kKeyTPMToken, token },
             { encrypt_param_keys::kKeyDeviceName, param.deviceDisplayName }
         };
+        stream << params;
 
-        fmDebug() << "Calling ChangePassphrase D-Bus method";
-        QDBusReply<bool> ret = iface.call("ChangePassphrase", params);
+        // Write credentials to pipe and close write end immediately
+        ssize_t written = write(pipefd[1], credentials.constData(), credentials.size());
+        close(pipefd[1]);   // Close write end immediately after writing
+
+        if (written != credentials.size()) {
+            fmCritical() << "Failed to write credentials to pipe, written:" << written << "expected:" << credentials.size();
+            close(pipefd[0]);
+            return;
+        }
+
+        // Create file descriptor for D-Bus transmission
+        QDBusUnixFileDescriptor fd(pipefd[0]);
+        if (!fd.isValid()) {
+            fmCritical() << "Failed to create valid file descriptor from pipe";
+            close(pipefd[0]);
+            return;
+        }
+
+        fmDebug() << "Calling ChangePassphrase D-Bus method via fd";
+        QDBusReply<bool> ret = iface.call("ChangePassphrase", QVariant::fromValue(fd));
         if (ret.value()) {
             QApplication::setOverrideCursor(Qt::WaitCursor);
         } else {
             fmCritical() << "Passphrase change failed to start";
         }
+
+        // Close read end (D-Bus service will have its own copy)
+        close(pipefd[0]);
     } else {
         fmCritical() << "Failed to create D-Bus interface for passphrase change";
     }
@@ -563,12 +632,60 @@ QString DiskEncryptMenuScene::getBase64Of(const QString &fileName)
     return QString(contents.toBase64());
 }
 
+bool DiskEncryptMenuScene::sendCredentialsViaFd(QDBusInterface &iface, const QString &method,
+                                                const QVariantMap &params, bool asyncCall)
+{
+    // Create anonymous pipe for secure credential transmission
+    int pipefd[2];
+    if (pipe(pipefd) == -1) {
+        fmCritical() << "[sendCredentialsViaFd] Failed to create anonymous pipe for credentials";
+        return false;
+    }
+
+    // Prepare credentials data using QDataStream for reliable serialization
+    QByteArray credentials;
+    QDataStream stream(&credentials, QIODevice::WriteOnly);
+    stream << params;
+
+    // Write credentials to pipe and close write end immediately
+    ssize_t written = write(pipefd[1], credentials.constData(), credentials.size());
+    close(pipefd[1]);   // Close write end immediately after writing
+
+    if (written != credentials.size()) {
+        fmCritical() << "[sendCredentialsViaFd] Failed to write credentials to pipe, written:" << written << "expected:" << credentials.size();
+        close(pipefd[0]);
+        return false;
+    }
+
+    // Create file descriptor for D-Bus transmission
+    QDBusUnixFileDescriptor fd(pipefd[0]);
+    if (!fd.isValid()) {
+        fmCritical() << "[sendCredentialsViaFd] Failed to create valid file descriptor from pipe";
+        close(pipefd[0]);
+        return false;
+    }
+
+    // Call D-Bus method with file descriptor
+    fmDebug() << "[sendCredentialsViaFd] Calling D-Bus method:" << method << "via fd";
+    if (asyncCall) {
+        iface.asyncCall(method, QVariant::fromValue(fd));
+    } else {
+        QDBusReply<bool> reply = iface.call(method, QVariant::fromValue(fd));
+        close(pipefd[0]);
+        return reply.value();
+    }
+
+    // Close read end (D-Bus service will have its own copy)
+    close(pipefd[0]);
+    return true;
+}
+
 void DiskEncryptMenuScene::onUnlocked(bool ok, dfmmount::OperationErrorInfo info, QString clearDev)
 {
     QApplication::restoreOverrideCursor();
     if (!ok && info.code != dfmmount::DeviceError::kUDisksErrorNotAuthorizedDismissed) {
         fmWarning() << "Unlock device failed:" << info.message;
-        dialog_utils::showDialog(tr("Unlock device failed"),
+        dialog_utils::showDialog(tr("Unlock partition failed"),
                                  tr("Wrong passphrase"),
                                  dialog_utils::kError);
         return;
@@ -681,7 +798,8 @@ void DiskEncryptMenuScene::updateActions()
     bool taskWorking = EventsHandler::instance()->isTaskWorking();
     bool currDevOperating = EventsHandler::instance()->isUnderOperating(param.devDesc)
             || EventsHandler::instance()->isUnderOperating(param.devPhy);
-    bool hasPendingJob = EventsHandler::instance()->hasPendingTask();
+    // 允许在存在加密配置的时候操作其他分区的加解密动作
+    bool hasPendingJob = 0 && EventsHandler::instance()->hasPendingTask();
     actions[kActIDEncrypt]->setEnabled(!taskWorking && !hasPendingJob);
     actions[kActIDDecrypt]->setEnabled(!taskWorking && !hasPendingJob && !currDevOperating);
     actions[kActIDChangePwd]->setEnabled(!taskWorking);
