@@ -24,6 +24,8 @@ private:
     void createAction(QMenu *menu, const QString &actName, bool isSubAct = false, bool checkable = false);
     void updateMenu(QMenu *menu);
     void updateSortMenu(QMenu *menu);
+    void updateGroupSubMenu(QMenu *menu);
+    void groupByRole(const QString &strategy);
     bool openFileLocation(const QString &path);
     void disableSubScene(DFMBASE_NAMESPACE::AbstractMenuScene *scene, const QString &sceneName);
 
