@@ -6,14 +6,16 @@
 #include "advancesearchbar_p.h"
 #include "utils/searchhelper.h"
 #include "utils/custommanager.h"
-#include "events/searcheventcaller.h"
 
 #include <dfm-base/widgets/filemanagerwindowsmanager.h>
 #include <dfm-base/interfaces/fileinfo.h>
 #include <dfm-base/utils/universalutils.h>
+#include <dfm-base/utils/sortutils.h>
 
 #include <dfm-framework/dpf.h>
 
+#include <QFileInfo>
+
 #include <DCommandLinkButton>
 #include <DHorizontalLine>
 #include <DLabel>
@@ -319,14 +321,18 @@ bool AdvanceSearchBarPrivate::shouldVisiableByFilterRule(SortFileInfo *info, QVa
 
     auto filterData = data.value<FilterData>();
     // 如果是重置过滤条件，则都显示
-    const auto &iter = std::find_if(filterData.begin() + 1, filterData.begin() + kLabelCount, [](const QVariant &value) {
+    const auto &iter = std::find_if(std::next(filterData.begin()), std::next(filterData.begin(), kLabelCount), [](const QVariant &value) {
         return value.isValid();
     });
-    if (filterData[kSearchRange].toBool() && (iter == filterData.begin() + kLabelCount || iter == filterData.end()))
+    if (filterData[kSearchRange].toBool() && (iter == std::next(filterData.begin(), kLabelCount) || iter == filterData.end()))
         return true;
 
     if (!info)
         return false;
+    // 检查文件是否存在，如果不存在则直接过滤掉
+    const auto &fileUrl = info->fileUrl();
+    if (fileUrl.isLocalFile() && !QFileInfo(fileUrl.toLocalFile()).exists())
+        return false;
 
     const auto &filter = parseFilterData(filterData);
 
@@ -352,7 +358,7 @@ bool AdvanceSearchBarPrivate::shouldVisiableByFilterRule(SortFileInfo *info, QVa
 
     // 检查文件类型过滤
     if (filter.comboValid[kFileType]) {
-        QString fileTypeStr = info->displayType();
+        QString fileTypeStr = SortUtils::accurateDisplayType(info->fileUrl());
         if (!fileTypeStr.startsWith(filter.typeString))
             return false;
     }
