@@ -26,7 +26,7 @@ void SmbBrowserEventCaller::sendOpenTab(quint64 windowId, const QUrl &url)
 
 bool SmbBrowserEventCaller::sendCheckTabAddable(quint64 windowId)
 {
-    return dpfSlotChannel->push("dfmplugin_workspace", "slot_Tab_Addable", windowId).toBool();
+    return dpfSlotChannel->push("dfmplugin_titlebar", "slot_Tab_Addable", windowId).toBool();
 }
 
 void SmbBrowserEventCaller::sendChangeCurrentUrl(quint64 windowId, const QUrl &url)
