@@ -123,6 +123,22 @@ void TitleBarEventCaller::sendTabRemoved(QWidget *sender, const QString &removed
     dpfSignalDispatcher->publish("dfmplugin_titlebar", "signal_Tab_Removed", windowId, removedId, nextId);
 }
 
+QString TitleBarEventCaller::sendColumnDisplyName(QWidget *sender, dfmbase::Global::ItemRoles role)
+{
+    quint64 id = TitleBarHelper::windowId(sender);
+    Q_ASSERT(id > 0);
+    auto name = dpfSlotChannel->push("dfmplugin_workspace", "slot_Model_ColumnDisplayName", id, role).toString();
+    return name;
+}
+
+QList<ItemRoles> TitleBarEventCaller::sendColumnRoles(QWidget *sender)
+{
+    quint64 id = TitleBarHelper::windowId(sender);
+    Q_ASSERT(id > 0);
+    auto roleList = dpfSlotChannel->push("dfmplugin_workspace", "slot_Model_ColumnRoles", id).value<QList<ItemRoles>>();
+    return roleList;
+}
+
 ViewMode TitleBarEventCaller::sendGetDefualtViewMode(const QString &scheme)
 {
     int defaultViewMode = dpfSlotChannel->push("dfmplugin_workspace", "slot_View_GetDefaultViewMode", scheme).toInt();
@@ -143,3 +159,17 @@ void TitleBarEventCaller::sendSetSort(QWidget *sender, ItemRoles role)
     Q_ASSERT(id > 0);
     dpfSlotChannel->push("dfmplugin_workspace", "slot_Model_SetSort", id, role);
 }
+
+QString TitleBarEventCaller::sendCurrentGroupRoleStrategy(QWidget *sender)
+{
+    quint64 id = TitleBarHelper::windowId(sender);
+    Q_ASSERT(id > 0);
+    return dpfSlotChannel->push("dfmplugin_workspace", "slot_Model_CurrentGroupStrategy", id).toString();
+}
+
+void TitleBarEventCaller::sendSetGroupStrategy(QWidget *sender, const QString &strategy)
+{
+    quint64 id = TitleBarHelper::windowId(sender);
+    Q_ASSERT(id > 0);
+    dpfSlotChannel->push("dfmplugin_workspace", "slot_Model_SetGroup", id, strategy);
+}
