@@ -18,6 +18,8 @@
 #include <dfm-base/utils/finallyutil.h>
 #include <dfm-base/utils/fileutils.h>
 #include <dfm-base/widgets/filemanagerwindowsmanager.h>
+#include <dfm-base/base/application/application.h>
+#include <dfm-base/base/application/settings.h>
 
 #include <dfm-framework/dpf.h>
 
@@ -31,6 +33,7 @@ DFMBASE_USE_NAMESPACE
 
 QMap<quint64, TitleBarWidget *> TitleBarHelper::kTitleBarMap {};
 QList<QString> TitleBarHelper::kKeepTitleStatusSchemeList {};
+QMap<QString, ViewModeUrlCallback> TitleBarHelper::kViewModeUrlCallbackMap {};
 
 bool TitleBarHelper::newWindowAndTabEnabled { true };
 bool TitleBarHelper::searchEnabled { false };
@@ -344,6 +347,18 @@ bool TitleBarHelper::checkKeepTitleStatus(const QUrl &url)
     return kKeepTitleStatusSchemeList.contains(scheme);
 }
 
+void TitleBarHelper::registerViewModelUrlCallback(const QString &scheme, ViewModeUrlCallback callback)
+{
+    if (!kViewModeUrlCallbackMap.contains(scheme))
+        kViewModeUrlCallbackMap.insert(scheme, callback);
+}
+
+ViewModeUrlCallback TitleBarHelper::viewModelUrlCallback(const QUrl &url)
+{
+    auto scheme = url.scheme();
+    return kViewModeUrlCallbackMap.value(scheme);
+}
+
 QMutex &TitleBarHelper::mutex()
 {
     static QMutex m;
@@ -380,3 +395,24 @@ QString TitleBarHelper::getDisplayName(const QString &name)
     displayName = displayName.isEmpty() ? name : displayName;
     return displayName;
 }
+
+QUrl TitleBarHelper::transformViewModeUrl(const QUrl &url)
+{
+    auto callback = viewModelUrlCallback(url);
+    return callback ? callback(url) : url;
+}
+
+QVariant TitleBarHelper::getFileViewStateValue(const QUrl &url, const QString &key, const QVariant &defaultValue)
+{
+    QUrl viewModeUrl = transformViewModeUrl(url);
+    QMap<QString, QVariant> valueMap = Application::appObtuselySetting()->value("FileViewState", viewModeUrl).toMap();
+    return valueMap.value(key, defaultValue);
+}
+
+void TitleBarHelper::setFileViewStateValue(const QUrl &url, const QString &key, const QVariant &value)
+{
+    QUrl viewModeUrl = transformViewModeUrl(url);
+    QVariantMap map = Application::appObtuselySetting()->value("FileViewState", viewModeUrl).toMap();
+    map[key] = value;
+    Application::appObtuselySetting()->setValue("FileViewState", viewModeUrl, map);
+}
