@@ -39,6 +39,14 @@ public:
     static void registerKeepTitleStatusScheme(const QString &scheme);
     static bool checkKeepTitleStatus(const QUrl &url);
 
+    static void registerViewModelUrlCallback(const QString &scheme, ViewModeUrlCallback callback);
+    static ViewModeUrlCallback viewModelUrlCallback(const QUrl &url);
+
+    // FileViewState unified access methods
+    static QVariant getFileViewStateValue(const QUrl &url, const QString &key, const QVariant &defaultValue = QVariant());
+    static void setFileViewStateValue(const QUrl &url, const QString &key, const QVariant &value);
+    static QUrl transformViewModeUrl(const QUrl &url);
+
 public:
     static bool newWindowAndTabEnabled;
     static bool searchEnabled;
@@ -49,6 +57,7 @@ private:
     static QString getDisplayName(const QString &name);
     static QMap<quint64, TitleBarWidget *> kTitleBarMap;
     static QList<QString> kKeepTitleStatusSchemeList;
+    static QMap<QString, ViewModeUrlCallback> kViewModeUrlCallbackMap;
 };
 
 }
