@@ -261,6 +261,9 @@ void TabBarPrivate::handleTabClicked(int index)
 
 void TabBarPrivate::handleIndexChanged(int index)
 {
+    if (currentTabIndex == index)
+        return;
+
     const auto &tab = tabInfo(index);
     if (tab.isInactive) {
         Q_EMIT q->requestCreateView(tab.uniqueId);
@@ -614,14 +617,14 @@ void TabBar::removeTab(int index, int selectIndex)
             newIndex = curIndex;
         } else if (curIndex == index) {
             // Delete current tab, select next tab (if last tab then select previous)
-            newIndex = (index == count() - 1) ? qMax(index - 1, 0) : index;
+            newIndex = (index == count() - 1) ? qMax(index - 1, 0) : index + 1;
         } else {
             // Current tab is after deleted tab, decrease index by 1
             newIndex = curIndex - 1;
         }
     }
 
-    Q_EMIT tabHasRemoved(index, newIndex);
+    Q_EMIT tabAboutToRemove(index, newIndex);
     setCurrentIndex(newIndex);
     DTabBar::removeTab(index);
 }
@@ -772,21 +775,19 @@ QMimeData *TabBar::createMimeDataFromTab(int index, const QStyleOptionTab &optio
 
 QPixmap TabBar::createDragPixmapFromTab(int index, const QStyleOptionTab &option, QPoint *hotspot) const
 {
-    const qreal ratio = qApp->devicePixelRatio();
     auto winid = FMWindowsIns.findWindowId(this);
     auto window = FMWindowsIns.findWindowById(winid);
     if (!window)
         return DTabBar::createDragPixmapFromTab(index, option, hotspot);
 
-    int width = window->width() * ratio;
-    int height = window->height() * ratio;
+    int width = window->width();
+    int height = window->height();
     QImage screenshotImage(width, height, QImage::Format_ARGB32_Premultiplied);
-    screenshotImage.setDevicePixelRatio(ratio);
     window->render(&screenshotImage, QPoint(), QRegion(0, 0, width, height));
 
     // scaled image to smaller.
-    int scaledWidth = width * ratio / 5;
-    int scaledHeight = height * ratio / 5;
+    int scaledWidth = width / 5;
+    int scaledHeight = height / 5;
     auto scaledImage = screenshotImage.scaled(scaledWidth, scaledHeight, Qt::IgnoreAspectRatio, Qt::SmoothTransformation);
 
     QImage backgroundImage(scaledWidth + 10, scaledHeight + 10, QImage::Format_ARGB32_Premultiplied);
@@ -803,7 +804,7 @@ QPixmap TabBar::createDragPixmapFromTab(int index, const QStyleOptionTab &option
     QPainterPath rectPath;
     QPainterPath roundedRectPath;
     rectPath.addRect(0, 0, scaledWidth + 10, scaledHeight + 10);
-    roundedRectPath.addRoundedRect(QRect(0, 0, scaledWidth / ratio + 10, scaledHeight / ratio + 10), 6, 6);
+    roundedRectPath.addRoundedRect(QRect(0, 0, scaledWidth + 10, scaledHeight + 10), 6, 6);
     rectPath -= roundedRectPath;
 
     painter.setCompositionMode(QPainter::CompositionMode_Source);
