@@ -22,15 +22,6 @@ class DFileChooserEdit;
 DWIDGET_END_NAMESPACE
 
 namespace dfmplugin_vault {
-class RadioFrame : public QFrame
-{
-    Q_OBJECT
-public:
-    explicit RadioFrame(QFrame *parent = nullptr);
-
-protected:
-    void paintEvent(QPaintEvent *event) override;
-};
 
 class VaultActiveSaveKeyFileView : public VaultBaseView
 {
@@ -45,12 +36,6 @@ private:
     void initConnect();
 
 public slots:
-    /*!
-     * /brief slotSelectRadioBtn  单选框选中槽函数
-     * /param btn   选中的单选框按钮
-     */
-    void slotSelectRadioBtn(QAbstractButton *btn);
-
     /*!
      * /brief slotChangeEdit 处理保存密钥路径权限问题,并在UI上进行提示
      * /param fileName      选择保存密钥的路径
@@ -69,17 +54,13 @@ private:
     DTK_WIDGET_NAMESPACE::DLabel *titleLabel { nullptr };
     //! 密钥文件安全提示
     DTK_WIDGET_NAMESPACE::DLabel *hintMsg { nullptr };
-    //! 默认保存单选框按钮
-    QRadioButton *defaultPathRadioBtn { nullptr };
-    //! 用户自定义保存单选框按钮
-    QRadioButton *otherPathRadioBtn { nullptr };
+    DTK_WIDGET_NAMESPACE::DLabel *otherPathLabel { Q_NULLPTR };
     //! 用户自定义保存路径编辑框
     DTK_WIDGET_NAMESPACE::DFileChooserEdit *selectfileSavePathEdit { nullptr };
     //! 保存密钥文件并进行下一步操作的按钮
     DTK_WIDGET_NAMESPACE::DSuggestButton *nextBtn { nullptr };
     //! 保存密钥权限提示
     DTK_WIDGET_NAMESPACE::DLabel *otherRadioBtnHitMsg { nullptr };
-    QButtonGroup *group { nullptr };
     DTK_WIDGET_NAMESPACE::DFileDialog *filedialog { nullptr };
 };
 }
