@@ -48,8 +48,8 @@ enum class ModelState : uint8_t {
 };
 
 enum class GroupingState : uint8_t {
-    kIdle,       // 未在分组或分组已完成
-    kGrouping    // 正在执行分组操作
+    kIdle,   // 未在分组或分组已完成
+    kGrouping   // 正在执行分组操作
 };
 #ifdef DTKWIDGET_CLASS_DSizeMode
 inline constexpr int kCompactIconViewSpacing { 0 };
@@ -88,7 +88,7 @@ inline constexpr int kMaxTabCount { 8 };
 // view select box
 inline constexpr int kSelectBoxLineWidth { 2 };
 
-namespace GroupStrategty {
+namespace GroupStrategy {
 inline constexpr char kNoGroup[] { "NoGroupStrategy" };
 inline constexpr char kName[] { "Name" };
 inline constexpr char kSize[] { "Size" };
@@ -97,7 +97,7 @@ inline constexpr char kCreatedTime[] { "CreatedTime" };
 inline constexpr char kType[] { "Type" };
 inline constexpr char kCustomPath[] { "CustomPath" };
 inline constexpr char kCustomTime[] { "CustomTime" };
-}   // namespace GroupStrategty
+}   // namespace GroupStrategy
 namespace PropertyKey {
 inline constexpr char kScheme[] { "Property_Key_Scheme" };
 inline constexpr char kKeepShow[] { "Property_Key_KeepShow" };
