@@ -402,13 +402,6 @@ QVariant FileViewModel::data(const QModelIndex &index, int role) const
         return {};
     }
 
-    // TODO: ui bug
-    // // 分组时可能耗时很久，此时若返回数据会导致界面异常
-    // if (groupingState() == GroupingState::kGrouping) {
-    //     fmDebug() << "Current grouping state is grouping, ignore data";
-    //     return {};
-    // }
-
     const QModelIndex &parentIndex = index.parent();
 
     if (filterSortWorker.isNull())
@@ -438,9 +431,9 @@ QVariant FileViewModel::data(const QModelIndex &index, int role) const
     }
 
     if (itemData->data(ItemRoles::kItemUrlRole).toUrl().scheme() == "group-header") {
-        QVariant groupHeaderVaule = filterSortWorker->groupHeaderData(index.row(), role);
-        if (groupHeaderVaule.isValid())
-            return groupHeaderVaule;
+        QVariant groupHeaderValue = filterSortWorker->groupHeaderData(index.row(), role);
+        if (groupHeaderValue.isValid())
+            return groupHeaderValue;
     }
 
     return itemData->data(columnRole);
@@ -1257,7 +1250,7 @@ void FileViewModel::initFilterSortWork()
     Qt::SortOrder order = static_cast<Qt::SortOrder>(WorkspaceHelper::instance()->getFileViewStateValue(dirRootUrl, "sortOrder", Qt::SortOrder::AscendingOrder).toInt());
     ItemRoles role = static_cast<ItemRoles>(WorkspaceHelper::instance()->getFileViewStateValue(dirRootUrl, "sortRole", kItemFileDisplayNameRole).toInt());
     // get group config
-    QString groupStrategy = WorkspaceHelper::instance()->getFileViewStateValue(dirRootUrl, "groupStrategy", GroupStrategty::kNoGroup).toString();
+    QString groupStrategy = WorkspaceHelper::instance()->getFileViewStateValue(dirRootUrl, "groupStrategy", GroupStrategy::kNoGroup).toString();
     Qt::SortOrder groupOrder = static_cast<Qt::SortOrder>(WorkspaceHelper::instance()->getFileViewStateValue(dirRootUrl, "groupingOrder", Qt::AscendingOrder).toInt());
     const QString &expandsionKey = QString("groupExpansion.%1").arg(groupStrategy);
     const auto &expansionStates = WorkspaceHelper::instance()->getFileViewStateValue(dirRootUrl, expandsionKey).toHash();
