@@ -105,13 +105,29 @@ FileView::~FileView()
 {
     fmInfo() << "Destroying FileView for URL:" << rootUrl();
 
-    disconnect(model(), &FileViewModel::stateChanged, this, &FileView::onModelStateChanged);
-    disconnect(selectionModel(), &QItemSelectionModel::selectionChanged, this, &FileView::onSelectionChanged);
+    // 关键修复: 必须在基类(QAbstractItemView)析构前解绑 model
+    // 原因: QAbstractItemView 持有 QPersistentModelIndex,如果 model 先于基类析构,
+    //      这些 QPersistentModelIndex 析构时会访问已释放的 model 导致崩溃
 
+    // 1. 断开信号连接
+    if (model()) {
+        disconnect(model(), nullptr, this, nullptr);
+    }
+    if (selectionModel()) {
+        disconnect(selectionModel(), nullptr, this, nullptr);
+    }
+
+    // 2. 解绑 model (关键步骤!)
+    // 这会触发 QAbstractItemView 清理所有 QPersistentModelIndex
+    DListView::setModel(nullptr);
+
+    // 3. 清理其他订阅
     dpfSignalDispatcher->unsubscribe("dfmplugin_workspace", "signal_View_HeaderViewSectionChanged", this, &FileView::onHeaderViewSectionChanged);
     dpfSignalDispatcher->unsubscribe("dfmplugin_filepreview", "signal_ThumbnailDisplay_Changed", this, &FileView::onWidgetUpdate);
 
     fmDebug() << "FileView destruction completed";
+
+    // 注意: model 作为 FileView 的子对象,会在基类析构后由 Qt 自动释放
 }
 
 QWidget *FileView::widget() const
@@ -245,6 +261,9 @@ bool FileView::setRootUrl(const QUrl &url)
     // This handles both initialization and directory switching scenarios
     d->adjustHeaderLayoutMargin(model()->groupingStrategy());
 
+    // 初始化分组状态追踪
+    d->previousGroupStrategy = model()->groupingStrategy();
+
     // dir already traversal
     if (model()->currentState() == ModelState::kIdle)
         updateSelectedUrl();
@@ -314,12 +333,27 @@ FileViewModel *FileView::model() const
 
 void FileView::setModel(QAbstractItemModel *model)
 {
-    if (model->parent() != this)
-        model->setParent(this);
-    auto curr = FileView::model();
-    if (curr)
-        delete curr;
-    DListView::setModel(model);
+    // 1. 获取旧 model
+    auto oldModel = FileView::model();
+
+    // 2. 先解绑旧 model (关键!)
+    // 必须先调用 DListView::setModel(nullptr) 来清理 QAbstractItemView 中的 QPersistentModelIndex
+    if (oldModel) {
+        DListView::setModel(nullptr);
+        // 只删除我们拥有的 model (通过 QObject 父子关系判断)
+        if (oldModel->QObject::parent() == this) {
+            delete oldModel;
+        }
+    }
+
+    // 3. 设置新 model
+    if (model) {
+        // 如果没有 parent,设置为 this,这样 Qt 会自动管理生命周期
+        if (!model->QObject::parent()) {
+            model->setParent(this);
+        }
+        DListView::setModel(model);
+    }
 }
 
 void FileView::stopWork(const QUrl &newUrl)
@@ -809,6 +843,9 @@ void FileView::setGroup(const QString &strategyName, const Qt::SortOrder order)
     fmInfo() << "Setting group strategy:" << strategyName << "order:" << (order == Qt::AscendingOrder ? "Ascending" : "Descending")
              << "for URL:" << rootUrl().toString();
 
+    // 在分组开始前保存当前的分组策略
+    d->previousGroupStrategy = model()->groupingStrategy();
+
     model()->grouping(strategyName, order);
 
     const QUrl &url = rootUrl();
@@ -1307,7 +1344,7 @@ bool FileView::isGroupedView() const
 {
     const auto strategyName = model()->groupingStrategy();
 
-    if (strategyName.isEmpty() || strategyName == GroupStrategty::kNoGroup)
+    if (strategyName.isEmpty() || strategyName == GroupStrategy::kNoGroup)
         return false;
 
     return true;
@@ -2171,6 +2208,21 @@ bool FileView::eventFilter(QObject *obj, QEvent *event)
 
 void FileView::paintEvent(QPaintEvent *event)
 {
+    // 仅在从无分组切换到有分组时才跳过绘制,避免UI异常
+    // 从一种分组策略切换到另一种分组策略时允许绘制,保持流畅性
+    if (model()->groupingState() == GroupingState::kGrouping) {
+        QString currentStrategy = model()->groupingStrategy();
+        bool isFromNoGroupToGrouped = (d->previousGroupStrategy == GroupStrategy::kNoGroup
+                                       && currentStrategy != GroupStrategy::kNoGroup);
+        if (isFromNoGroupToGrouped) {
+            fmDebug() << "Skipping paint during initial grouping from none to:" << currentStrategy;
+            return;
+        }
+        // 允许分组间切换时的绘制
+        fmDebug() << "Allow paint during group-to-group switch from:"
+                  << d->previousGroupStrategy << "to:" << currentStrategy;
+    }
+
     if (d->animationHelper->isWaitingToPlaying() || d->animationHelper->isAnimationPlaying()) {
         d->animationHelper->paintItems();
         itemDelegate()->hideAllIIndexWidget();
@@ -2296,7 +2348,6 @@ void FileView::initializeConnect()
     connect(model(), &FileViewModel::dataChanged, this, &FileView::updateOneView);
     connect(model(), &FileViewModel::renameFileProcessStarted, this, &FileView::onRenameProcessStarted);
     connect(model(), &FileViewModel::aboutToSwitchToListView, this, &FileView::onAboutToSwitchListView);
-
     connect(selectionModel(), &QItemSelectionModel::selectionChanged, this, &FileView::onSelectionChanged);
 
     connect(this, &DListView::rowCountChanged, this, &FileView::onRowCountChanged, Qt::QueuedConnection);
@@ -2446,7 +2497,7 @@ void FileView::updateLoadingIndicator()
     if (state == ModelState::kBusy) {
         QString tip;
 
-        const FileInfoPointer &fileInfo = model()->fileInfo(rootIndex());
+        FileInfoPointer fileInfo = InfoFactory::create<FileInfo>(rootUrl());
         if (fileInfo)
             tip = fileInfo->viewOfTip(ViewInfoType::kLoading);
 
