@@ -15,28 +15,31 @@ NormalDecryptWorker::NormalDecryptWorker(const QVariantMap &args, QObject *paren
 
 void NormalDecryptWorker::run()
 {
-    qInfo() << "about to decrypt normal device...";
+    qInfo() << "[NormalDecryptWorker::run] Starting normal device decryption";
 
     using namespace disk_encrypt::encrypt_param_keys;
     auto devPath = m_args.value(kKeyDevice, "").toString();
+    qInfo() << "[NormalDecryptWorker::run] About to decrypt normal device:" << devPath;
+
     auto fd = inhibit_helper::inhibit(tr("Decrypting ") + devPath);
 
     auto devPass = disk_encrypt::fromBase64(m_args.value(kKeyPassphrase, "").toString());
     auto devName = m_args.value(kKeyDeviceName, "").toString();
+    qDebug() << "[NormalDecryptWorker::run] Device name:" << devName;
 
     auto status = crypt_setup_helper::encryptStatus(devPath);
     if (status & disk_encrypt::kStatusOnline && status & disk_encrypt::kStatusEncrypt) {
-        qWarning() << "device is not fully encrypted, cannot decrypt!" << devPath;
+        qCritical() << "[NormalDecryptWorker::run] Device is not fully encrypted, cannot decrypt, device:" << devPath << "status:" << status;
         setExitCode(-disk_encrypt::kErrorNotFullyEncrypted);
         return;
     }
 
     int r = crypt_setup::csDecryptMoveHead(devPath, devPass, devName);
     if (r < 0) {
-        qWarning() << "device decrypt failed!" << devPath;
+        qCritical() << "[NormalDecryptWorker::run] Device decrypt failed, device:" << devPath << "error:" << r;
         setExitCode(r);
         return;
     }
 
-    qInfo() << "normal device decrypted." << devPath;
+    qInfo() << "[NormalDecryptWorker::run] Normal device decrypted successfully, device:" << devPath;
 }
