@@ -6,6 +6,7 @@
 #include "units/unitlist.h"
 
 #include <QLoggingCategory>
+#include <QElapsedTimer>
 
 Q_DECLARE_LOGGING_CATEGORY(logToolUpgrade)
 using namespace dfm_upgrade;
@@ -17,15 +18,15 @@ UpgradeFactory::UpgradeFactory()
 void UpgradeFactory::previous(const QMap<QString, QString> &args)
 {
     units = createUnits();
-    qCInfo(logToolUpgrade) << QString("load %0 units").arg(units.size());
-
+    qCInfo(logToolUpgrade) << QString("Successfully loaded %1 units").arg(units.size());
     for (auto unit = units.begin(); unit != units.end();) {
         QString name = (*unit)->name();
-        qCInfo(logToolUpgrade) << "initialize unit" << name;
+        qCInfo(logToolUpgrade) << "Initializing unit:" << name;
         if (!(*unit)->initialize(args)) {
-            qCCritical(logToolUpgrade) << "fail to init" << name;
+            qCCritical(logToolUpgrade) << "Failed to initialize unit:" << name;
             unit = units.erase(unit);
         } else {
+            qCInfo(logToolUpgrade) << "Successfully initialized unit:" << name;
             unit++;
         }
     }
@@ -35,9 +36,9 @@ void UpgradeFactory::doUpgrade()
 {
     for (auto unit = units.begin(); unit != units.end(); unit++) {
         QString name = (*unit)->name();
-        qCInfo(logToolUpgrade) << "upgrade unit" << name;
+        qCInfo(logToolUpgrade) << "Starting upgrade for unit:" << name;
         if (!(*unit)->upgrade()) {
-            qCCritical(logToolUpgrade) << "fail to upgrade" << name;
+            qCCritical(logToolUpgrade) << "Failed to upgrade unit:" << name;
         }
     }
 }
@@ -46,7 +47,7 @@ void UpgradeFactory::completed()
 {
     for (auto unit = units.begin(); unit != units.end(); unit++) {
         QString name = (*unit)->name();
-        qCInfo(logToolUpgrade) << "complete unit" << name;
+        qCInfo(logToolUpgrade) << "Completing unit:" << name;
         (*unit)->completed();
     }
 }
